Generates a Trelliscope display for distributional characteristics across all variables.
trellis_vismi(
data,
imp_list,
m = NULL,
imp_idx = NULL,
integerAsFactor = FALSE,
title = "auto",
subtitle = "auto",
color_pal = NULL,
marginal_x = "box+rug",
nrow = 2,
ncol = 4,
path = NULL,
verbose = FALSE,
...
)A Trelliscope display object visualising distributional characteristics for all variables.
A data frame containing the original data with missing values.
A list of imputed data frames.
An integer specifying the number of imputed datasets to plot. It should be smaller than length(imp_list). Default is NULL (plot all).
A vector of integers specifying the indices of imputed datasets to plot. Default is NULL (plot all).
A logical value indicating whether to treat integer variables as factors (TRUE) or numeric (FALSE). Default is FALSE.
A string specifying the title of the plot. Default is "auto" (automatic title based on x,y,z input). If NULL, no title is shown.
A string specifying the subtitle of the plot. Default is "auto" (automatic subtitle based on x,y,z input). If NULL, no subtitle is shown.
A named vector of colors for different imputation sets. If NULL (default), a default color palette is used.
A character string specifying the type of marginal plot to add for the x variable in 2D plots. Options are "hist", "box", "rug", "box+rug", or NULL (default, no marginal plot) when interactive = TRUE. Options are "box", "rug", "box+rug", or NULL (default, no marginal plot) when interactive = FALSE.
Number of rows in the Trelliscope display. Default is 2.
Number of columns in the Trelliscope display. Default is 4.
Optional path to save the Trelliscope display. If NULL, the display will not be saved to disk.
A logical value indicating whether to print extra information. Default is FALSE.
Additional arguments passed to the underlying plotting functions, such as point_size, alpha, nbins, width, and boxpoints.
trellis_vismi(data = nhanes3, imp_list = imp_nhanes3, marginal_x = "box")
Run the code above in your browser using DataLab